use log::error;
use ovlach_data::cv::cv::CV;
use rocket::{get, State, response::Redirect, http::Status};
use rocket_dyn_templates::Template;
use serde::Serialize;

use crate::{PresentationConfig, services::cv::fetch_cv_data_from_backend, CVBackendConfig, tools::rocket::RequestLanguage};

#[derive(Serialize, Debug)]
struct RootPage {
    static_host: String,
    cv: CV,
    download_cv_url: String,
    lang: String,
}

#[get("/<language>")]
pub async fn index(presentation_config: &State<PresentationConfig>, cv_config: &State<CVBackendConfig>, language: RequestLanguage) -> Result<Template, Status> {
    let context = match fetch_cv_data_from_backend(cv_config.cv_backend_path.clone()).await {
        Ok(cv) => RootPage {
            static_host: presentation_config.static_route.clone(),
            cv,
            download_cv_url: "FIXME!".to_string(),
            lang: language.language,
        },
        Err(e) => {
            error!("Can't fetch CV data from backend {:?}", e);
            return Err(Status::InternalServerError)
        }
    };

    Ok(Template::render("default", &context))
}


#[get("/")]
pub fn index_without_lang() -> Redirect {
    // Default language is czech (TODO: config)
    Redirect::to(format!("{}/{}", "", "cs"))
}
